@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.6.0, released
- *  on Wed Apr 19 15:50:57 UTC 2023
+ *  This file is part of MUMPS 5.7.2, released
+ *  on Mon Jun 17 08:20:17 UTC 2024
  *
  *
- *  Copyright 1991-2023 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2024 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -16,6 +16,7 @@
 #ifndef MUMPS_SAVE_RESTORE_C_H
 #define MUMPS_SAVE_RESTORE_C_H
 #include "mumps_common.h"
+#if ! defined(NO_SAVE_RESTORE)
 #define MUMPS_GET_SAVE_DIR_C \
     F_SYMBOL(get_save_dir_c,GET_SAVE_DIR_C)
 void MUMPS_CALL
@@ -24,6 +25,7 @@ MUMPS_GET_SAVE_DIR_C(MUMPS_INT *len_save_dir, char* save_dir, mumps_ftnlen l1);
     F_SYMBOL(get_save_prefix_c,GET_SAVE_PREFIX_C)
 void MUMPS_CALL
 MUMPS_GET_SAVE_PREFIX_C(MUMPS_INT *len_save_prefix, char* save_prefix, mumps_ftnlen l1);
+#endif
 #define MUMPS_SAVE_RESTORE_RETURN_C \
     F_SYMBOL(save_restore_return_c,SAVE_RESTORE_RETURN_C)
 void MUMPS_CALL
